==> mule-datasense-4.0.0-rc-sources.jar: org/mule/datasense/impl/model/ast/MuleFlowNode.java <==
package org.mule.datasense.impl.model.ast;

import org.mule.datasense.impl.model.annotations.ComponentLocationAnnotation;
import org.mule.runtime.api.component.ComponentIdentifier;
import org.mule.runtime.api.component.location.ComponentLocation;
import org.mule.runtime.api.component.location.Location;

import com.google.common.base.Preconditions;
import org.mule.runtime.config.spring.api.dsl.model.ComponentModel;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Stream;

public class MuleFlowNode extends BaseAstNode {

  private final MessageProcessorNode rootMessageProcessorNode;
  private final ComponentModel componentModel;
  private AstNode parentAstNode;

  private Map<ComponentLocation, MessageProcessorNode> messageProcessorNodeMap;

  public MuleFlowNode(ComponentIdentifier componentIdentifier, ComponentModel componentModel,
                      MessageProcessorNode rootMessageProcessorNode) {
    super(componentIdentifier);
    this.componentModel = componentModel;
    Preconditions.checkNotNull(componentModel);
    setName(componentModel.getNameAttribute());
    this.rootMessageProcessorNode = rootMessageProcessorNode;
    messageProcessorNodeMap = new HashMap<>();
  }

  public MuleFlowNode(ComponentIdentifier componentIdentifier, ComponentModel componentModel) {
    this(componentIdentifier, componentModel, null);
  }

  public AstNode getParentAstNode() {
    return parentAstNode;
  }

  public ComponentModel getComponentModel() {
    return componentModel;
  }

  public void setParentAstNode(AstNode parentAstNode) {
    this.parentAstNode = parentAstNode;
  }

  public Optional<MessageProcessorNode> getRootMessageProcessorNode() {
    return Optional.ofNullable(rootMessageProcessorNode);
  }

  @Override
  public <T> Object accept(AstNodeVisitor<T> astNodeVisitor, T context) {
    return astNodeVisitor.visit(this, context);
  }

  public void register(ComponentLocation componentLocation, MessageProcessorNode messageProcessorNode) {
    Preconditions.checkState(!findMessageProcessorNode(componentLocation.getLocation()).isPresent(),
                             String.format("Node already registered for componentLocation %s", componentLocation.getLocation()));

    messageProcessorNodeMap.put(componentLocation, messageProcessorNode);
  }

  public Optional<MessageProcessorNode> findMessageProcessorNode(String location) {
    return messageProcessorNodeMap.entrySet().stream()
        .filter(messageProcessorNode -> messageProcessorNode.getKey().getLocation().equals(location)).map(
                                                                                                          Map.Entry::getValue)
        .findFirst();
  }

  public Stream<MessageProcessorNode> findMessageProcessorNodes(boolean includeRoot) {
    return messageProcessorNodeMap.values().stream()
        .filter(messageProcessorNode -> includeRoot || !messageProcessorNode.isRootMessageProcessorNode());
  }

  public Stream<MessageProcessorNode> findMessageProcessorNodes() {
    return findMessageProcessorNodes(false);
  }

}

==> mule-datasense-4.5.0-20220125-sources.jar: org/mule/datasense/impl/model/ast/MuleFlowNode.java <==
package org.mule.datasense.impl.model.ast;

import org.mule.runtime.api.component.ComponentIdentifier;
import org.mule.runtime.api.component.location.ComponentLocation;
import org.mule.runtime.ast.api.ComponentAst;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Stream;

import com.google.common.base.Preconditions;

public class MuleFlowNode extends BaseAstNode {

  private final MessageProcessorNode rootMessageProcessorNode;
  private final ComponentAst componentModel;
  private AstNode parentAstNode;

  private final Map<ComponentLocation, MessageProcessorNode> messageProcessorNodeMap;

  public MuleFlowNode(ComponentIdentifier componentIdentifier, ComponentAst componentModel,
                      MessageProcessorNode rootMessageProcessorNode) {
    super(componentIdentifier);
    this.componentModel = componentModel;
    Preconditions.checkNotNull(componentModel);
    setName(componentModel.getComponentId().orElse(null));
    this.rootMessageProcessorNode = rootMessageProcessorNode;
    messageProcessorNodeMap = new HashMap<>();
  }

  public MuleFlowNode(ComponentIdentifier componentIdentifier, ComponentAst componentModel) {
    this(componentIdentifier, componentModel, null);
  }

  public AstNode getParentAstNode() {
    return parentAstNode;
  }

  public ComponentAst getComponentModel() {
    return componentModel;
  }

  public void setParentAstNode(AstNode parentAstNode) {
    this.parentAstNode = parentAstNode;
  }

  public Optional<MessageProcessorNode> getRootMessageProcessorNode() {
    return Optional.ofNullable(rootMessageProcessorNode);
  }

  @Override
  public <T> Object accept(AstNodeVisitor<T> astNodeVisitor, T context) {
    return astNodeVisitor.visit(this, context);
  }

  public void register(ComponentLocation componentLocation, MessageProcessorNode messageProcessorNode) {
    Preconditions.checkState(!findMessageProcessorNode(componentLocation.getLocation()).isPresent(),
                             String.format("Node already registered for componentLocation %s", componentLocation.getLocation()));

    messageProcessorNodeMap.put(componentLocation, messageProcessorNode);
  }

  public Optional<MessageProcessorNode> findMessageProcessorNode(String location) {
    return messageProcessorNodeMap.entrySet().stream()
        .filter(messageProcessorNode -> messageProcessorNode.getKey().getLocation().equals(location)).map(
                                                                                                          Map.Entry::getValue)
        .findFirst();
  }

  public Stream<MessageProcessorNode> findMessageProcessorNodes(boolean includeRoot) {
    return messageProcessorNodeMap.values().stream()
        .filter(messageProcessorNode -> includeRoot || !messageProcessorNode.isRootMessageProcessorNode());
  }

  public Stream<MessageProcessorNode> findMessageProcessorNodes() {
    return findMessageProcessorNodes(false);
  }

}
